<script type="text/javascript">
'use strict';

var ncConfig = {
  maxAttempts:30,
  checkingInterval:15000,
  singularLabel:' New Post',
  pluralLabel:' New Posts',
  maxNewPosts: 20,
  streamUpdatedDelay: 1500,
  infiniteScrollThreshold: 700,
  showMoreBtnClickDelay:500,
  domQueries:{
    showMoreBtn: 'ul.lotusPagingBottom li.pagingHandler a.streamMore',
    selectedFilter:'[id^="com_ibm_social_as_filter_FilterList"] a.filterSelected',
    rssFeedLink:'div[id^="com_ibm_social_as_feed_FeedLink"] a',
    container: '.lotusStream .lotusWidgetBody .streamHeaderWrapper .icStream-search'
  },
  loginUrl:'/homepage/login'
};


(function(){

  var originalTitle = document.title,
    xhrHookAdded = false,
    numStories = 0,
    startTimestamp, container, notifierBtn, checking, checkInterval, xhr, overrideTimestamp;

  var init = function(){
    originalTitle = document.title;
    startTimestamp = overrideTimestamp || (new Date()).toISOString();
    overrideTimestamp = null;
    addDojoXhrHook();
    mapSelectedFilterEvent();
    mapInfiniteScrollEvent();
    if(container){
      if(notifierBtn) dojo.destroy(notifierBtn);
      notifierBtn = dojo.create('div',{className:'activity-stream-notify-area lotusHidden', innerHTML:''}, container,'after');
      dojo.connect(notifierBtn,'click',function(){
        var selectedFilter = dojo.query(ncConfig.domQueries.selectedFilter);
        if(selectedFilter && selectedFilter.length===1 && selectedFilter[0]) fireClickEvent(selectedFilter[0]);
        resetState();
      });
    }

    if(!checking){
      checking = true;
      checkInterval = setInterval(check, ncConfig.checkingInterval);
    }
  };

  var filterClickEvent;
  var mapSelectedFilterEvent = function(){
    var selectedFilter = dojo.query(ncConfig.domQueries.selectedFilter);
    if(selectedFilter && selectedFilter.length===1 && selectedFilter[0]){
      if(filterClickEvent) dojo.disconnect(filterClickEvent);
      filterClickEvent = dojo.connect(selectedFilter[0], 'click', resetState);
    }
  };

  var dojoXhrHook = function(xhrType, args){
    if(xhrType==='POST' && args && args.url.indexOf('connections/opensocial/')>-1){
      var callbackProp = args.load ? 'load' : args.handle ? 'handle' : null;
      if(callbackProp){
        var oldCallback = args[callbackProp];
        args[callbackProp] = function(){
          streamUpdated();
          return oldCallback.apply(this,arguments);
        };
      }
    }
  };

  var addDojoXhrHook = function(){
    if(xhrHookAdded) return;
    xhrHookAdded = true;
    var oldXhr = dojo.xhr;
    dojo.xhr = function(){
      dojoXhrHook.apply(this,arguments);
      return oldXhr.apply(this, arguments);
    }
  };

  var resetState = function(){
    if(originalTitle) document.title = originalTitle;
    numStories = 0;
    init();
  };

  var scrollEvent,scrollTimeout = false, scrollCount=0,intervalCount=0 ;
  var mapInfiniteScrollEvent = function(){
    if(scrollEvent) dojo.disconnect(scrollEvent);
    scrollEvent = dojo.connect(window, 'scroll', function(){
      // console.log('called scroll', scrollCount++);
      if(scrollTimeout) clearTimeout(scrollTimeout);
      scrollTimeout = setTimeout(scrollFunc, 200);
    });
  };

  var lastClick = new Date();
  var scrollFunc = function(){
    // console.log('called scrollfunc', intervalCount++);
    var scrollPos = getScrollTop();
    var documentHeight = getDocHeight();
    var windowHeight = window.innerHeight;
    // console.log('scrolling window', scrollPos, documentHeight, windowHeight);
    if(scrollPos >= documentHeight - windowHeight - ncConfig.infiniteScrollThreshold){
      var thisClick = (new Date()).getTime();
      if(thisClick - lastClick < ncConfig.showMoreBtnClickDelay) return;
      var showMoreBtn = dojo.query(ncConfig.domQueries.showMoreBtn);
      if(showMoreBtn && showMoreBtn.length==1 && dojo.style(showMoreBtn[0],'display'!=='none')){
        lastClick = thisClick;
        fireClickEvent(showMoreBtn[0]);
      }
      else
        console.error('InfiniteScroller: No Show More btn found', ncConfig.domQueries.showMoreBtn);
    }
  };

  function getDocHeight() {
    var D = document;
    return Math.max(
      Math.max(D.body.scrollHeight,D.documentElement.scrollHeight),
      Math.max(D.body.offsetHeight, D.documentElement.offsetHeight),
      Math.max(D.body.clientHeight, D.documentElement.clientHeight)
    );
  }

  function getScrollTop(){
    if(typeof pageYOffset!= 'undefined'){
        //most browsers except IE before #9
        return pageYOffset;
    }
    else{
        var B= document.body; //IE 'quirks'
        var D= document.documentElement; //IE with doctype
        D= (D.clientHeight)? D: B;
        return D.scrollTop;
    }
  }


  var streamUpdated = function(){
    if(numStories==0){
      setTimeout(function(){
        getStartTime(function(timestamp){ //get start time from the first entry to account for server-client time diff
          // console.log('streamUpdated newtimestamp',timestamp);
          if(timestamp) overrideTimestamp = timestamp;
          resetState();
        });
      }, ncConfig.streamUpdatedDelay);
    }
  };

  var getFeedUrl = function(newOnly){
    var url;
    var feedLink = dojo.query(ncConfig.domQueries.rssFeedLink);
    if(feedLink && feedLink.length===1 && feedLink[0].href.indexOf('javascript')===-1) {
      url = feedLink[0].href+'&format=json'+(newOnly? '&updatedSince='+startTimestamp : '');
      url = url.replace(/\&format=atom/,'');
      // console.log('got url',url);
    }
    return url;
  };

  var getStartTime = function(done){
    getEntries(function(data){
      var feedData = dojo.fromJson(data);
      done(feedData.list[0].published);
    },function(){done((new Date()).toISOString());});
  };

  var getNumNewStories = function(done){
    getEntries(function(data){
      var feedData = dojo.fromJson(data);
      // if(feedData.list.length>0) console.log('found new entry with date', feedData.list[0].published);
      done(feedData.list.length);
    },function(){done(0);}, true);
  };

  var getEntries = function(load,error,newOnly){
    if(xhr) xhr.cancel();
    xhr = dojo.xhrGet({
      url: getFeedUrl(newOnly),
      handleAs:'text',
      handle:function(response){
        xhr = null;
        if(response.status===401){
          console.log('Authentication timed out');
          window.location = ncConfig.loginUrl;
        }
      },
      load:load,
      error: function(err){
        if (err.dojoType==='cancel') { return; }
        console.error(err);
        error.apply(this,arguments);
      }
    });
  };

  var check = function(){
    getNumNewStories(function(numNewStories){
      if(numNewStories>0 && notifierBtn){
        numStories = numNewStories;
        dojo.removeClass(notifierBtn,'lotusHidden');
        var numLabel = (numNewStories > ncConfig.maxNewPosts ? ncConfig.maxNewPosts+'+' : numNewStories);
        notifierBtn.innerHTML = numLabel + (numNewStories>1 ? ncConfig.pluralLabel : ncConfig.singularLabel);
        document.title = '('+numLabel+')'+' '+originalTitle;
        if(numNewStories>ncConfig.maxNewPosts) {
          checking = false;
          clearInterval(checkInterval);
        }
      }
    });
  };

  var numAttemptsForDojo = 0;

  var mapLoadEvent = function(){
    if(dojo){
      dojo.addOnLoad(mapHashChangeEvent);
      dojo.addOnLoad(fnCallOnLoad);
    }
    else if(numAttemptsForDojo++ <= ncConfig.maxAttempts)
      setTimeout(mapLoadEvent, 1000);
  };



  var currentHref = window.location.href;
  var mapHashChangeEvent = function(){
    //map method to onHashChange event
    if (('onhashchange' in window) && (!dojo.isIE || dojo.isIE > 7)){
      var hashFunc = window.onhashchange;
      window.onhashchange = function() {
        if(typeof hashFunc==='function')
        hashFunc();
        fnCallOnLoad();
      };
    } else {	//if the event is not available then create a callback function to check if the url has changed
      setInterval(function() {
        var newHref = window.location.href;
        if (currentHref !== newHref) {
          currentHref = newHref;
          fnCallOnLoad();
        }
      }, 1000);
    }
  };
  var numAttemptsForDomRender = 0, numAttemptsForJsLoad = 0;
  var fnCallOnLoad = function(){
    try{
      if(ibmConfig){
        if(ibmConfig.serviceName==='homepage' && window.location.pathname.indexOf('updates')>-1){
          container = dojo.query(ncConfig.domQueries.container);
          if(container.length===1){
            container = container[0];
            init();
          }
          else if(numAttemptsForDomRender++ <=ncConfig.maxAttempts)
          setTimeout(fnCallOnLoad,1000);
        }
      }
      else if(numAttemptsForJsLoad++ <=ncConfig.maxAttempts)
      setTimeout(fnCallOnLoad, 1000);
    }
    catch(e) {
      console.error('fnCallOnLoad: ', e);
    }
  };

  var fireClickEvent = function(el){
    if(document.createEvent) {
      var event = document.createEvent('MouseEvents');
      event.initEvent( 'click', true, false );
      el.dispatchEvent( event );

    } else if(document.createEventObject && el.fireEvent) {
      var event = document.createEventObject();
      el.fireEvent( 'onclick', event );
    }
  };

  mapLoadEvent();

})();

</script>

<style type="text/css">
.activity-stream-notify-area {
    text-align:center;
    color: white;
    font-weight:bold;
    font-size:1.2em;
    background: #1F7CAE;
    border: none;
    padding: 10px;
    cursor: pointer;
}

.activity-stream-notify-area:hover {
	background: #6FB4DA;
}
</style>
